<?php

namespace Drupal\eca_webform\Event;

use Drupal\Core\Session\AccountInterface;

/**
 * Provides element access event for eca_webform.
 *
 * @package Drupal\eca_webform\Event
 */
class ElementAccessAlter extends WebformBaseEvent {

  /**
   * An element create, view, or update operation.
   *
   * @var string
   */
  protected string $operation;

  /**
   * Webform specific element properties.
   *
   * @var array
   */
  protected array $element;

  /**
   * The optional user account.
   *
   * @var \Drupal\Core\Session\AccountInterface|null
   */
  protected ?AccountInterface $account;

  /**
   * The element's current context.
   *
   * @var array
   */
  protected array $context;

  /**
   * Constructs the ElementAccessAlter event.
   *
   * @param string $operation
   *   An element create, view, or update operation.
   * @param array $element
   *   Webform specific element properties.
   * @param \Drupal\Core\Session\AccountInterface|null $account
   *   (optional) If provided, only those formats that are allowed for this user
   *   account will be returned. All enabled formats will be returned otherwise.
   *   Defaults to NULL.
   * @param array $context
   *   The element's current context which include the webform and
   *   webform submission entity.
   */
  public function __construct(string $operation, array &$element, AccountInterface $account = NULL, array $context = []) {
    $this->operation = $operation;
    $this->element = &$element;
    $this->account = $account;
    $this->context = $context;
  }

  /**
   * The operation.
   *
   * @return string
   *   An element create, view, or update operation.
   */
  public function getOperation(): string {
    return $this->operation;
  }

  /**
   * The element.
   *
   * @return array
   *   Webform specific element properties.
   */
  public function &getElement(): array {
    return $this->element;
  }

  /**
   * The user account.
   *
   * @return \Drupal\Core\Session\AccountInterface|null
   *   The user account.
   */
  public function getAccount(): ?AccountInterface {
    return $this->account;
  }

  /**
   * The context.
   *
   * @return array
   *   The element's current context.
   */
  public function getContext(): array {
    return $this->context;
  }

}
